@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 import functools
 from importlib import import_module
 
@@ -36,3 +34,11 @@ def safe(function):
         return mark_safe(function(*args, **kwargs))
     return _decorator
 
+
+def reraise(tp, value, tb=None):
+    if value is None:
+        value = tp()
+    if value.__traceback__ is not tb:
+        raise value.with_traceback(tb)
+    raise value
+
